unit Options;

interface

uses
  Commons.Settings,
  System.Collections,
  System.Reflection,
  System.Xml.Serialization,
  System.Windows.Forms;

type
  TOptions = class(TSettingsObject)
  strict private
    procedure AfterCreation;
  public
    [XmlIgnore]
    UnitPostfix: string;
    [XmlIgnore]
    UsesIndent: string;
    [XmlIgnore]
    KnownNamespaceHash: HashTable;
  public
    ClassPrefix: string;
    Indent: Integer;
    AddPrefixDefault: Boolean;
    RemoveUnprefixedDefault: Boolean;
    PrefixUnitPath: string;
    ItemInterfaceShortcut: Keys;
    ItemImplementationShortcut: Keys;
    ItemRemoveNonPrefixShortCut: Keys;
  public
    class function Load: TOptions;
    constructor Create;
  end;

implementation

uses
  System.IO;

class function TOptions.Load: TOptions;
begin
  try
    Result := TOptions.LoadFrom(Path.GetDirectoryName(Assembly.GetExecutingAssembly.Location) + Path.DirectorySeparatorChar + 'PUses.xml') as TOptions;
  except
    Result := TOptions.Create;
  end;
  Result.AfterCreation;
end;

constructor TOptions.Create;
begin
  inherited Create;
  KnownNamespaceHash := HashTable.Create;
  ClassPrefix := 'T';
  Indent := 2;
  AddPrefixDefault := true;
  RemoveUnprefixedDefault := false;
  PrefixUnitPath := '';
  ItemInterfaceShortcut := Keys.None;
  ItemImplementationShortcut := Keys.None;
  ItemRemoveNonPrefixShortCut := Keys.None;
end;

procedure TOptions.AfterCreation;
var
  Files: array of string;
  S: string;
  I: Integer;
begin
  UnitPostfix := '.' + ClassPrefix.ToUpper;
  UsesIndent := System.string.Create(' ',Indent);
  KnownNamespaceHash.Clear;
  try
    Files := Directory.GetFileSystemEntries(PrefixUnitPath,'*.pas');
    for I := 0 to Pred(Length(Files)) do begin
      S := Path.GetFileNameWithoutExtension(Files[I]).ToUpper;
      if S.ToUpper.EndsWith(UnitPostfix) and (S <> ('SYSTEM' + UnitPostfix)) then
        KnownNamespaceHash.Add(S.Substring(0,S.Length - UnitPostfix.Length),nil);
    end;
  except
    ;
  end;
  if KnownNamespaceHash.Count = 0 then
    AddPrefixDefault := false;
end;


end.
